import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

/** DemoGridLayout - program to demonstrate the
* <code>GridLayout</code> class.<p>
*
* Usage:<p>
*
* <pre>
*     java DemoGridLayout arg1
*
*     where 'arg1' = strut size in pixels
* </pre>
*
* Invocations:<p>
*
* <pre>
*     java DemoGridLayout 0
* </pre>
* <center><img src="DemoGridLayout-1.gif"></center><p>
* <pre>
*     java DemoGridLayout 10
* </pre>
* <center><img src="DemoGridLayout-2.gif"></center><p>
*
* @see <a href="DemoGridLayout.java">source code</a>
* @author Scott MacKenzie, 2009-2011
*/
public class DemoGridLayout
{
   public static void main(String[] args)
   {
      if (args.length != 1)
      {
         usage();
         return;
      }

      int strutSize = Integer.parseInt(args[0]);

      // use look and feel for my system (Win32)
      try {
         UIManager.setLookAndFeel(
            UIManager.getSystemLookAndFeelClassName());
      } catch (Exception e) {}

      DemoGridLayoutFrame frame = new DemoGridLayoutFrame(strutSize);
      frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
      frame.setTitle("DemoGridLayout");
      frame.pack();
      frame.setVisible(true);
   }

   private static void usage()
   {
      System.out.println(
         "usage: java DemoGridLayout arg1\n\n" +
         "where 'arg1' = strut size in pixels"
      );
      return;
   }
}

class DemoGridLayoutFrame extends JFrame
{
	// the following avoids a "warning" with Java 1.5.0 complier (?)
	static final long serialVersionUID = 42L;

   private JButton b1;
   private JButton b2;
   private JButton b3;
   private JButton b4;
   private JButton b5;

   public DemoGridLayoutFrame(int strutArg)
   {
      // ----------------------------------
      // construct and configure components
      // ----------------------------------

      b1 = new JButton("Carrot");
      b2 = new JButton("Yam");
      b3 = new JButton("Broccoli");
      b4 = new JButton("Brussel Sprouts");
      b5 = new JButton("Zucchini");

      // -----------------
      // layout components
      // -----------------

      JPanel panel = new JPanel();

      // use GridLayout with struts, as per command-line arg
      int hGap = strutArg;
      int vGap = strutArg;
      panel.setLayout(new GridLayout(3, 2, hGap, vGap));

      panel.add(b1);
      panel.add(b2);
      panel.add(b3);
      panel.add(b4);
      panel.add(b5);

      // for in-class demo...
      //panel.setPreferredSize(new Dimension(175, 175));

      // for in-class demo...
      //System.out.println("panel : " + panel.getPreferredSize());

      // make panel this JFrame's content pane

      this.setContentPane(panel);

   }
}
