import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

/** <b>Programming Challenge</b><br>
*
* Write a java GUI application to create the following
* component layout:<p>
*
* <center><img src = "PC_LayoutExample.gif"></center><p>
*
* Make sure the program responds appropriately when the application
* window is resized.  Note, as well, that both buttons are the
* same size.<p>
*
* Name the program <code>PC_LayoutExample.java</code><p>
*
* @see <a href="PC_LayoutExample.java">source code</a>
* @author Scott MacKenzie, 2007
*/
public class PC_LayoutExample
{
   public static void main(String[] args)
   {
      // use look and feel for my system (Win32)
      try {
         UIManager.setLookAndFeel(
            UIManager.getSystemLookAndFeelClassName());
      } catch (Exception e) {}

      PC_LayoutExampleFrame frame = new PC_LayoutExampleFrame();
      frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
      frame.setTitle("PC_LayoutExample");
      frame.pack();
      frame.setVisible(true);
   }
}

class PC_LayoutExampleFrame extends JFrame
{
   // the following avoids a "warning" with Java 1.5.0 complier (?)
	static final long serialVersionUID = 42L;

   private JLabel label;
   private JButton clear;
   private JButton exit;
   private JTextArea input;

   public PC_LayoutExampleFrame()
   {
      // ----------------------------------
      // construct and configure components
      // ----------------------------------

      label = new JLabel("Enter some text:");
      clear = new JButton("Clear");
      exit = new JButton("Exit");
      exit.setPreferredSize(clear.getPreferredSize());

      input = new JTextArea();
      input.setPreferredSize(new Dimension(200, 100));
      input.setBorder(BorderFactory.createLineBorder(Color.black));

      // -----------------
      // layout components
      // -----------------

      JPanel buttonPanel = new JPanel();
      buttonPanel.setLayout(new BoxLayout(buttonPanel, BoxLayout.X_AXIS));
      buttonPanel.add(Box.createHorizontalGlue());
      buttonPanel.add(clear);
      buttonPanel.add(Box.createRigidArea(new Dimension(5, 0)));
      buttonPanel.add(exit);
      buttonPanel.setBorder(BorderFactory.createEmptyBorder(0, 10, 0, 0));

      JPanel panel = new JPanel(new BorderLayout(15, 15));
		panel.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
		panel.add(label, "North");
      panel.add(input, "Center");
      panel.add(buttonPanel, "South");

      // make panel this JFrame's content pane

      this.setContentPane(panel);
   }
}
